@@ -1,10 +1,10 @@
 import copy
-import math
 import os
 import re
 import sys
 import tempfile
 from curses import ascii
+from pathlib import Path
 
 import fsutil
 from fontTools import unicodedata
@@ -16,6 +16,7 @@ from fontTools.varLib.instancer import OverlapMode
 from PIL import Image, ImageDraw, ImageFont
 
 from fontbro.flags import get_flag, set_flag
+from fontbro.math import get_euclidean_distance
 from fontbro.subset import parse_unicodes
 from fontbro.utils import concat_names, read_json, slugify
 
@@ -215,12 +216,12 @@ class Font:
         self._kwargs = None
         self._ttfont = None
 
-        if isinstance(filepath, str):
-            self._init_with_filepath(filepath, **kwargs)
+        if isinstance(filepath, (Path, str)):
+            self._init_with_filepath(str(filepath), **kwargs)
         else:
             filepath_type = type(filepath).__name__
             raise ValueError(
-                f"Invalid filepath type: expected str, found {filepath_type!r}."
+                f"Invalid filepath type: expected pathlib.Path or str, found {filepath_type!r}."
             )
 
     def _init_with_filepath(self, filepath, **kwargs):
@@ -804,13 +805,6 @@ class Font:
         if not self.is_variable():
             return None
 
-        def get_euclidean_distance(a, b):
-            # https://en.wikipedia.org/wiki/Euclidean_distance#Higher_dimensions
-            keys = set(list(a.keys()) + list(b.keys()))
-            return math.sqrt(
-                sum([math.pow(a.get(key, 0) - b.get(key, 0), 2) for key in keys])
-            )
-
         lookup_values = coordinates
         instances = self.get_variable_instances()
         closest_instance_distance = sys.maxsize
@@ -1290,7 +1284,7 @@ class Font:
         # instantiate the sliced variable font
         instancer.instantiateVariableFont(font, coordinates, inplace=True, **options)
 
-    def to_static(self, coordinates=None, **options):
+    def to_static(self, coordinates=None, style_name=None, **options):
         """
         Converts the variable font to a static one pinning
         the variable axes at the given coordinates.
@@ -1299,6 +1293,8 @@ class Font:
 
         :param coordinates: The coordinates, eg. {'wght':500, 'ital':50}
         :type coordinates: dict or None
+        :param style_name: The existing instance style name, eg. 'Black'
+        :type style_name: str or None
         :param options: The options for the fontTools.varLib.instancer
         :type options: dictionary
 
@@ -1310,6 +1306,22 @@ class Font:
 
         font = self.get_ttfont()
 
+        # take coordinates from instance with specified style name
+        if style_name:
+            if coordinates:
+                raise ValueError(
+                    "Invalid arguments: 'coordinates' and 'style_name' are mutually exclusive."
+                )
+            instances = self.get_variable_instances()
+            for instance in instances:
+                if slugify(instance["style_name"]) == slugify(style_name):
+                    coordinates = instance["coordinates"].copy()
+                    break
+            if not coordinates:
+                raise ValueError(
+                    f"Invalid style name: instance with style name {style_name!r} not found."
+                )
+
         # make coordinates more friendly by using default axis values by default
         coordinates = coordinates or {}
         default_coordinates = {
